////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
// Copyright (c) Qualcomm Technologies, Inc. and/or its subsidiaries.
// All Rights Reserved.
// Confidential and Proprietary - Qualcomm Technologies, Inc.
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// THIS IS AUTO-GENERATED CODE.  PLEASE DO NOT EDIT (File bug reports against tools).
///
/// Auto-generated by: Parameter Parser V5.5.1 (2411131018)
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @file  awbrstatsprocessor.cpp
/// @brief Auto-generated Chromatix parameter file
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////

#include "awbrstatsprocessor.h"
#include "parametersetmanager.h"

AWBRSTATSPROCESSOR_NAMESPACE_BEGIN

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// SetValue/GetValue Functions
/// Gets or sets the requested value
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool refPtDataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "refPt") == 0)
    {
        if (__index < 15)
        {
            __result = refPt[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool refPtDataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "refPt") == 0)
    {
        if (__index < 15)
        {
            __result = refPt[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool refPtDataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // refPt
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("refPt", ParameterParserDataType::Structure, true, false, 15));
    }
    else if (PARAMETER_STRCMP(__name, "refPt") == 0)
    {
        if (__index < 15)
        {
            __result = refPt[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, 15));
        }
    }

    return __result;
}

bool subSamplingType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        ParameterUtils::DoubleToString((double)enable, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "subSampling") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)subSampling, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool subSamplingType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            enable = (BOOL)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "subSampling") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            subSampling = (awbSubSamplingPattern)(UINT32)dblValue; 
        }
    }

    return __result;
}

bool subSamplingType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enable
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enable", ParameterParserDataType::Boolean, (double)enable, 0));
    }
    else if (PARAMETER_STRCMP(__name, "enable") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Boolean, (double)enable, 0));
    }

    // subSampling
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("subSampling", ParameterParserDataType::Enum, (double)(UINT32)subSampling, 0));
    }
    else if (PARAMETER_STRCMP(__name, "subSampling") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)subSampling, 0));
    }

    return __result;
}

bool AGWType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "confidence") == 0)
    {
        __result = confidence.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool AGWType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "confidence") == 0)
    {
        __result = confidence.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool AGWType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // confidence
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("confidence", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "confidence") == 0)
    {
        __result = confidence.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool awbMLCZoneConfigType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "Description") == 0)
    {
        PARAMETER_STRCPY(__value, __size, Description);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "groupID") == 0)
    {
        ParameterUtils::DoubleToString((double)groupID, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "zoneType") == 0)
    {
        ParameterUtils::DoubleToString((double)(UINT32)zoneType, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "triggerCtrlType") == 0)
    {
        if (__index < 3)
        {
            ParameterUtils::DoubleToString((double)(UINT32)triggerCtrlType[__index], __value, __size, 0);
            __result = true;
        }
        else
        {
            SIZE_T __valuePos = 0;
            for (UINT32 i = 0; i < 3; i++)
            {
                if (i > 0)
                {
                    PARAMETER_STRCAT(__value, __size, ",");
                    __valuePos = PARAMETER_STRLEN(__value);
                }
                ParameterUtils::DoubleToString((double)(UINT32)triggerCtrlType[i], &__value[__valuePos], (INT32)(__size - __valuePos), 0);
            }
            __result = true;
        }
    }

    return __result;
}

bool awbMLCZoneConfigType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "Description") == 0)
    {
        // Cannot modify strings, risk of memory leaks or corruption
    }
    else if (PARAMETER_STRCMP(__name, "groupID") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            groupID = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "zoneType") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            zoneType = (awbrglobalelements::awbZoneType)(UINT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "triggerCtrlType") == 0)
    {
        if (__index < 3)
        {
            const double dblValue = ParameterUtils::StringToDouble(__value, __result);
            if (__result)
            {
                triggerCtrlType[__index] = (awbMLCZTriggerCtrlType)(UINT32)dblValue; 
            }
        }
        else
        {
            SIZE_T __valueLen = PARAMETER_STRLEN(__value);
            UINT32 __pos = 0;

            __index = 0;
            while (__pos < __valueLen && __index < 3)
            {
                CHAR __valueStr[MAX_SIZE];

                __pos += ParameterUtils::GetSubString(&__value[__pos], ',', __valueStr, MAX_SIZE);
                __pos++;

                const double dblValue = ParameterUtils::StringToDouble(__valueStr, __result);
                if (__result)
                {
                    triggerCtrlType[__index] = (awbMLCZTriggerCtrlType)(UINT32)dblValue; 
                }
                __index++;
            }
            __result = true;
        }
    }

    return __result;
}

bool awbMLCZoneConfigType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // Description
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("Description", ParameterParserDataType::String, Description));
    }
    else if (PARAMETER_STRCMP(__name, "Description") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::String, Description));
    }

    // groupID
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("groupID", ParameterParserDataType::Int32, (double)groupID, 0));
    }
    else if (PARAMETER_STRCMP(__name, "groupID") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)groupID, 0));
    }

    // zoneType
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("zoneType", ParameterParserDataType::Enum, (double)(UINT32)zoneType, 0));
    }
    else if (PARAMETER_STRCMP(__name, "zoneType") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Enum, (double)(UINT32)zoneType, 0));
    }

    // triggerCtrlType
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerCtrlType", ParameterParserDataType::Enum, true, false, 3));
    }

    return __result;
}

bool awbMLCZoneDefineType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "zoneConfigData") == 0)
    {
        __result = zoneConfigData.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "zone") == 0)
    {
        __result = zone.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool awbMLCZoneDefineType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "zoneConfigData") == 0)
    {
        __result = zoneConfigData.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "zone") == 0)
    {
        __result = zone.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool awbMLCZoneDefineType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // zoneConfigData
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("zoneConfigData", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "zoneConfigData") == 0)
    {
        __result = zoneConfigData.GetInfo(&__path[__pos], __info);
    }

    // zone
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("zone", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "zone") == 0)
    {
        __result = zone.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool MLCZType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enableFlag") == 0)
    {
        ParameterUtils::DoubleToString((double)enableFlag, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "detectionZone") == 0)
    {
        if (__index < detectionZoneCount)
        {
            __result = detectionZone[__index].GetValue(&__path[__pos], __value, __size);
        }
    }
    else if (PARAMETER_STRCMP(__name, "MLCZ") == 0)
    {
        if (__index < MLCZCount)
        {
            __result = MLCZ[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool MLCZType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enableFlag") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            enableFlag = (awbrglobalelements::enableFlagType)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "detectionZone") == 0)
    {
        if (__index < detectionZoneCount)
        {
            __result = detectionZone[__index].SetValue(&__path[__pos], __value);
        }
    }
    else if (PARAMETER_STRCMP(__name, "MLCZ") == 0)
    {
        if (__index < MLCZCount)
        {
            __result = MLCZ[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool MLCZType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enableFlag
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enableFlag", ParameterParserDataType::Int32, (double)enableFlag, 0));
    }
    else if (PARAMETER_STRCMP(__name, "enableFlag") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)enableFlag, 0));
    }

    // detectionZone
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("detectionZone", ParameterParserDataType::Structure, true, false, detectionZoneCount));
    }
    else if (PARAMETER_STRCMP(__name, "detectionZone") == 0)
    {
        if (__index < detectionZoneCount)
        {
            __result = detectionZone[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, detectionZoneCount));
        }
    }

    // MLCZ
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("MLCZ", ParameterParserDataType::Structure, true, false, MLCZCount));
    }
    else if (PARAMETER_STRCMP(__name, "MLCZ") == 0)
    {
        if (__index < MLCZCount)
        {
            __result = MLCZ[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, MLCZCount));
        }
    }

    return __result;
}

bool distWVDataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enableFlag") == 0)
    {
        ParameterUtils::DoubleToString((double)enableFlag, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "weight") == 0)
    {
        __result = weight.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool distWVDataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enableFlag") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            enableFlag = (awbrglobalelements::enableFlagType)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "weight") == 0)
    {
        __result = weight.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool distWVDataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enableFlag
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enableFlag", ParameterParserDataType::Int32, (double)enableFlag, 0));
    }
    else if (PARAMETER_STRCMP(__name, "enableFlag") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)enableFlag, 0));
    }

    // weight
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("weight", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "weight") == 0)
    {
        __result = weight.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool illuminantWVDataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enableFlag") == 0)
    {
        ParameterUtils::DoubleToString((double)enableFlag, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "weight") == 0)
    {
        __result = weight.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool illuminantWVDataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enableFlag") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            enableFlag = (awbrglobalelements::enableFlagType)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "weight") == 0)
    {
        __result = weight.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool illuminantWVDataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enableFlag
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enableFlag", ParameterParserDataType::Int32, (double)enableFlag, 0));
    }
    else if (PARAMETER_STRCMP(__name, "enableFlag") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)enableFlag, 0));
    }

    // weight
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("weight", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "weight") == 0)
    {
        __result = weight.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool AWBScreeningLevel3Type::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        __result = triggerData.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool AWBScreeningLevel3Type::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        __result = triggerData.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool AWBScreeningLevel3Type::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // triggerPt
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerPt", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetInfo(&__path[__pos], __info);
    }

    // triggerData
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerData", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        __result = triggerData.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool AWBScreeningLevel2Type::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool AWBScreeningLevel2Type::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool AWBScreeningLevel2Type::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // triggerPt
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerPt", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetInfo(&__path[__pos], __info);
    }

    // triggerData
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerData", ParameterParserDataType::Structure, true, false, triggerDataCount));
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, triggerDataCount));
        }
    }

    return __result;
}

bool AWBScreeningLevel1Type::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool AWBScreeningLevel1Type::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool AWBScreeningLevel1Type::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // triggerPt
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerPt", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetInfo(&__path[__pos], __info);
    }

    // triggerData
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerData", ParameterParserDataType::Structure, true, false, triggerDataCount));
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, triggerDataCount));
        }
    }

    return __result;
}

bool AWBTriggerScreeningType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].GetValue(&__path[__pos], __value, __size);
        }
    }

    return __result;
}

bool AWBTriggerScreeningType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].SetValue(&__path[__pos], __value);
        }
    }

    return __result;
}

bool AWBTriggerScreeningType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // triggerPt
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerPt", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "triggerPt") == 0)
    {
        __result = triggerPt.GetInfo(&__path[__pos], __info);
    }

    // triggerData
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("triggerData", ParameterParserDataType::Structure, true, false, triggerDataCount));
    }
    else if (PARAMETER_STRCMP(__name, "triggerData") == 0)
    {
        if (__index < triggerDataCount)
        {
            __result = triggerData[__index].GetInfo(&__path[__pos], __info);
        }
        else
        {
            __result = true;
            __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Structure, true, false, triggerDataCount));
        }
    }

    return __result;
}

bool statScreeningDataType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enableFlag") == 0)
    {
        ParameterUtils::DoubleToString((double)enableFlag, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "darkThreshold") == 0)
    {
        __result = darkThreshold.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "saturationThreshold") == 0)
    {
        __result = saturationThreshold.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool statScreeningDataType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "enableFlag") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            enableFlag = (awbrglobalelements::enableFlagType)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "darkThreshold") == 0)
    {
        __result = darkThreshold.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "saturationThreshold") == 0)
    {
        __result = saturationThreshold.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool statScreeningDataType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // enableFlag
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("enableFlag", ParameterParserDataType::Int32, (double)enableFlag, 0));
    }
    else if (PARAMETER_STRCMP(__name, "enableFlag") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)enableFlag, 0));
    }

    // darkThreshold
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("darkThreshold", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "darkThreshold") == 0)
    {
        __result = darkThreshold.GetInfo(&__path[__pos], __info);
    }

    // saturationThreshold
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("saturationThreshold", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "saturationThreshold") == 0)
    {
        __result = saturationThreshold.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool awbStatsProcessorType::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "moduleID") == 0)
    {
        __result = moduleID.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "statScreeningData") == 0)
    {
        __result = statScreeningData.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "illuminantWVData") == 0)
    {
        __result = illuminantWVData.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "distWVData") == 0)
    {
        __result = distWVData.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "MLCZ") == 0)
    {
        __result = MLCZ.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "agw") == 0)
    {
        __result = agw.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "SSType") == 0)
    {
        __result = SSType.GetValue(&__path[__pos], __value, __size);
    }
    else if (PARAMETER_STRCMP(__name, "refPtData") == 0)
    {
        __result = refPtData.GetValue(&__path[__pos], __value, __size);
    }

    return __result;
}

bool awbStatsProcessorType::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "moduleID") == 0)
    {
        __result = moduleID.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "statScreeningData") == 0)
    {
        __result = statScreeningData.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "illuminantWVData") == 0)
    {
        __result = illuminantWVData.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "distWVData") == 0)
    {
        __result = distWVData.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "MLCZ") == 0)
    {
        __result = MLCZ.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "agw") == 0)
    {
        __result = agw.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "SSType") == 0)
    {
        __result = SSType.SetValue(&__path[__pos], __value);
    }
    else if (PARAMETER_STRCMP(__name, "refPtData") == 0)
    {
        __result = refPtData.SetValue(&__path[__pos], __value);
    }

    return __result;
}

bool awbStatsProcessorType::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    const UINT32 __pos = ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // moduleID
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("moduleID", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "moduleID") == 0)
    {
        __result = moduleID.GetInfo(&__path[__pos], __info);
    }

    // module_version
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("module_version", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "module_version") == 0)
    {
        __result = module_version.GetInfo(&__path[__pos], __info);
    }

    // statScreeningData
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("statScreeningData", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "statScreeningData") == 0)
    {
        __result = statScreeningData.GetInfo(&__path[__pos], __info);
    }

    // illuminantWVData
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("illuminantWVData", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "illuminantWVData") == 0)
    {
        __result = illuminantWVData.GetInfo(&__path[__pos], __info);
    }

    // distWVData
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("distWVData", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "distWVData") == 0)
    {
        __result = distWVData.GetInfo(&__path[__pos], __info);
    }

    // MLCZ
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("MLCZ", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "MLCZ") == 0)
    {
        __result = MLCZ.GetInfo(&__path[__pos], __info);
    }

    // agw
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("agw", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "agw") == 0)
    {
        __result = agw.GetInfo(&__path[__pos], __info);
    }

    // SSType
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("SSType", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "SSType") == 0)
    {
        __result = SSType.GetInfo(&__path[__pos], __info);
    }

    // refPtData
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("refPtData", ParameterParserDataType::Structure));
    }
    else if (PARAMETER_STRCMP(__name, "refPtData") == 0)
    {
        __result = refPtData.GetInfo(&__path[__pos], __info);
    }

    return __result;
}

bool awbStatsProcessorType::module_versionStruct::GetValue(
    const CHAR* const __path,
    CHAR* const       __value,
    UINT32 const      __size)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)major_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)minor_revision, __value, __size, 0);
        __result = true;
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        ParameterUtils::DoubleToString((double)incr_revision, __value, __size, 0);
        __result = true;
    }

    return __result;
}

bool awbStatsProcessorType::module_versionStruct::SetValue(
    const CHAR* const __path,
    const CHAR* const __value)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            major_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            minor_revision = (INT32)dblValue; 
        }
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        const double dblValue = ParameterUtils::StringToDouble(__value, __result);
        if (__result)
        {
            incr_revision = (INT32)dblValue; 
        }
    }

    return __result;
}

bool awbStatsProcessorType::module_versionStruct::GetInfo(
    const CHAR* const           __path,
    PList<ParameterParserInfo>& __info)
{
    constexpr SIZE_T MAX_SIZE = 129;
    CHAR   __name[MAX_SIZE] = "";
    UINT32 __index          = MAX_UINT;
    bool   __result         = false;

    ParameterUtils::GetVariable(__path, __name, __index, MAX_SIZE);

    // major_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("major_revision", ParameterParserDataType::Int32, (double)major_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "major_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)major_revision, 0));
    }

    // minor_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("minor_revision", ParameterParserDataType::Int32, (double)minor_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "minor_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)minor_revision, 0));
    }

    // incr_revision
    if (__name[0] == '\0')
    {
        __result = true;
        __info.Add(ParameterParserInfo("incr_revision", ParameterParserDataType::Int32, (double)incr_revision, 0));
    }
    else if (PARAMETER_STRCMP(__name, "incr_revision") == 0)
    {
        __result = true;
        __info.Add(ParameterParserInfo(nullptr, ParameterParserDataType::Int32, (double)incr_revision, 0));
    }

    return __result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @brief Read enum value
/// @param entry [in] Symbol table entry
/// @param enumValue [out] Enum value to read
/// @param alignment [in] Symbol table byte alignment
/// @return true if successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ReadEnum_awbSubSamplingPattern(
    ParameterFileSymbolTableEntry* const entry,
    awbSubSamplingPattern& enumValue,
    BYTE const alignment)
{
    bool result {false};

    UINT32 uintValue {entry->ReadEnum(&result, alignment)};

    if (result)
    {
        switch (uintValue)
        {
        case static_cast<UINT32>(awbSubSamplingPattern::SubSamplingOff):
            enumValue = awbSubSamplingPattern::SubSamplingOff;
            result    = true;
            break;
        case static_cast<UINT32>(awbSubSamplingPattern::SubSampling_2):
            enumValue = awbSubSamplingPattern::SubSampling_2;
            result    = true;
            break;
        case static_cast<UINT32>(awbSubSamplingPattern::SubSampling_4):
            enumValue = awbSubSamplingPattern::SubSampling_4;
            result    = true;
            break;
        case static_cast<UINT32>(awbSubSamplingPattern::SubSampling_6):
            enumValue = awbSubSamplingPattern::SubSampling_6;
            result    = true;
            break;
        case static_cast<UINT32>(awbSubSamplingPattern::SubSampling_12):
            enumValue = awbSubSamplingPattern::SubSampling_12;
            result    = true;
            break;
        case static_cast<UINT32>(awbSubSamplingPattern::SubSampling_OneSample):
            enumValue = awbSubSamplingPattern::SubSampling_OneSample;
            result    = true;
            break;
        default:
            PARAMETER_LOG_ERROR(entry->SetManager, "Invalid value(% u) converting UINT32 to awbSubSamplingPattern", uintValue);
            break;
        }
    }
    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// @brief Read enum value
/// @param entry [in] Symbol table entry
/// @param enumValue [out] Enum value to read
/// @param alignment [in] Symbol table byte alignment
/// @return true if successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool ReadEnum_awbMLCZTriggerCtrlType(
    ParameterFileSymbolTableEntry* const entry,
    awbMLCZTriggerCtrlType& enumValue,
    BYTE const alignment)
{
    bool result {false};

    UINT32 uintValue {entry->ReadEnum(&result, alignment)};

    if (result)
    {
        switch (uintValue)
        {
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlLuxIdx):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlLuxIdx;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlCCT):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlCCT;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlValidStatsCntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlValidStatsCntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlAgwRg):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlAgwRg;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlAgwBg):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlAgwBg;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup0CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup0CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup1CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup1CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup2CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup2CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup3CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup3CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup4CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup4CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup5CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup5CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup6CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup6CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup7CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup7CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup8CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup8CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup9CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup9CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType0):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType0;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType1):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType1;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType2):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType2;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType3):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType3;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType4):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType4;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType5):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType5;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType6):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType6;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType7):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType7;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType8):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType8;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType9):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType9;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType10):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType10;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType11):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlInformationType11;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup10CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup10CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup11CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup11CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup12CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup12CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup13CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup13CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup14CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup14CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup15CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup15CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup16CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup16CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup17CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup17CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup18CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup18CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup19CntRatio):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlZoneGroup19CntRatio;
            result    = true;
            break;
        case static_cast<UINT32>(awbMLCZTriggerCtrlType::MLCZTriggerCtrlTypeMax):
            enumValue = awbMLCZTriggerCtrlType::MLCZTriggerCtrlTypeMax;
            result    = true;
            break;
        default:
            PARAMETER_LOG_ERROR(entry->SetManager, "Invalid value(% u) converting UINT32 to awbMLCZTriggerCtrlType", uintValue);
            break;
        }
    }
    return result;
}


////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Default Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
awbStatsProcessorTypeClass::awbStatsProcessorTypeClass(
    const CHAR* const name)
    : ParameterModule(name, MAJOR, MINOR, PATCH, nullptr)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(moduleID);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(statScreeningData);
    PARAMETER_INITIALIZE(illuminantWVData);
    PARAMETER_INITIALIZE(distWVData);
    PARAMETER_INITIALIZE(MLCZ);
    PARAMETER_INITIALIZE(agw);
    PARAMETER_INITIALIZE(SSType);
    PARAMETER_INITIALIZE(refPtData);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Constructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
awbStatsProcessorTypeClass::awbStatsProcessorTypeClass(
    const CHAR* const name,
    ModuleData* const moduleData)
    : ParameterModule(name, MAJOR, MINOR, PATCH, moduleData)
{
    PARAMETER_INITIALIZE(SymbolTableID);
    PARAMETER_INITIALIZE(moduleID);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(statScreeningData);
    PARAMETER_INITIALIZE(illuminantWVData);
    PARAMETER_INITIALIZE(distWVData);
    PARAMETER_INITIALIZE(MLCZ);
    PARAMETER_INITIALIZE(agw);
    PARAMETER_INITIALIZE(SSType);
    PARAMETER_INITIALIZE(refPtData);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Destructor
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
awbStatsProcessorTypeClass::~awbStatsProcessorTypeClass()
{
    if (Loaded)
    {
        UnloadModule();
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// GetName
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
const CHAR* awbStatsProcessorTypeClass::GetName(
    const CHAR* const type)
{
    const CHAR* name = type;
    CHAR temp[ParameterFileSymbolTableEntry::TYPE_LEN + 1];
    if (PARAMETER_STRCMP(type, ModuleData::GetType(temp, "awbrstatsprocessor")) == 0)
    {
        name = "awbrstatsprocessor";
    }
    return name;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load refPtDataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool refPtDataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(refPt);

    for (UINT32 i = 0; result && i < 15; i++)
    {
        result = refPt[i].Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load subSamplingType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool subSamplingType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enable);
    PARAMETER_INITIALIZE(subSampling);

    SYMBOL_TABLE_ENTRY_READ(entry, result, enable, alignment)
    if (result)
    {
        result = awbrstatsprocessor::ReadEnum_awbSubSamplingPattern(entry, subSampling, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load AGWType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool AGWType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(confidence);

    result = confidence.Load(entry, alignment);

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load awbMLCZoneConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool awbMLCZoneConfigType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(Description);
    PARAMETER_INITIALIZE(groupID);
    PARAMETER_INITIALIZE(zoneType);
    PARAMETER_INITIALIZE(triggerCtrlType);


    // Reading String Description from symbol table
    {
        UINT32 count = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, count, alignment)
        ParameterFileSymbolTableEntry stringPointerEntryCls;
        ParameterFileSymbolTableEntry* const stringPointerEntry = &stringPointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(stringPointerEntryCls, entry, alignment);
        }
        SYMBOL_TABLE_ENTRY_READ_STRING(stringPointerEntry, result, Description, count, alignment)
    }
    SYMBOL_TABLE_ENTRY_READ(entry, result, groupID, alignment)
    if (result)
    {
        result = awbrglobalelements::ReadEnum_awbZoneType(entry, zoneType, alignment);
    }
    for (UINT32 i = 0; result && i < 3; i++)
    {
        if (result)
        {
            result = awbrstatsprocessor::ReadEnum_awbMLCZTriggerCtrlType(entry, triggerCtrlType[i], alignment);
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load awbMLCZoneDefineType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool awbMLCZoneDefineType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(zoneConfigData);
    PARAMETER_INITIALIZE(zone);

    result = zoneConfigData.Load(entry, alignment);
    if (result)
    {
        result = zone.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load MLCZType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool MLCZType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enableFlag);
    PARAMETER_INITIALIZE(detectionZone);
    PARAMETER_INITIALIZE(MLCZ);

    SYMBOL_TABLE_ENTRY_READ(entry, result, enableFlag, alignment)

    // Reading Array detectionZone from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        detectionZoneCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, detectionZoneCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            detectionZoneID = pointerEntry->ID;
            DupObjInfo* detectionZoneDupInfo = pointerEntry->GetDupObject(detectionZoneCount, file, line);
            if (detectionZoneDupInfo != nullptr && detectionZoneDupInfo->Object != nullptr)
            {
                detectionZone = (awbMLCZoneDefineType*)detectionZoneDupInfo->Object;
                if (detectionZone == nullptr)
                {
                    if (detectionZoneDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "detectionZone duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            detectionZoneDupInfo->File, detectionZoneDupInfo->Line, detectionZoneDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "detectionZone duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            detectionZoneDupInfo->Line, detectionZoneDupInfo->RefCount);
                    }
                }
            }

            if (detectionZone == nullptr)
            {
                if (result && detectionZoneCount > 0)
                {
                    detectionZone = PARAMETER_NEW awbMLCZoneDefineType[detectionZoneCount];
                    (void)pointerEntry->SetDupObject(detectionZone, detectionZoneCount, file, line);
                }
                if (!result || detectionZone == nullptr)
                {
                    if (detectionZoneCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate detectionZone\n");
                    }
                    detectionZoneCount = 0;
                }
                for (UINT32 i = 0; result && i < detectionZoneCount; i++)
                {
                    result = detectionZone[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (detectionZone == nullptr)
        {
            detectionZoneCount = 0;
        }
    }

    // Reading Array MLCZ from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        MLCZCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, MLCZCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            MLCZID = pointerEntry->ID;
            DupObjInfo* MLCZDupInfo = pointerEntry->GetDupObject(MLCZCount, file, line);
            if (MLCZDupInfo != nullptr && MLCZDupInfo->Object != nullptr)
            {
                MLCZ = (awbMLCZoneDefineType*)MLCZDupInfo->Object;
                if (MLCZ == nullptr)
                {
                    if (MLCZDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "MLCZ duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            MLCZDupInfo->File, MLCZDupInfo->Line, MLCZDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "MLCZ duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            MLCZDupInfo->Line, MLCZDupInfo->RefCount);
                    }
                }
            }

            if (MLCZ == nullptr)
            {
                if (result && MLCZCount > 0)
                {
                    MLCZ = PARAMETER_NEW awbMLCZoneDefineType[MLCZCount];
                    (void)pointerEntry->SetDupObject(MLCZ, MLCZCount, file, line);
                }
                if (!result || MLCZ == nullptr)
                {
                    if (MLCZCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate MLCZ\n");
                    }
                    MLCZCount = 0;
                }
                for (UINT32 i = 0; result && i < MLCZCount; i++)
                {
                    result = MLCZ[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (MLCZ == nullptr)
        {
            MLCZCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load distWVDataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool distWVDataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enableFlag);
    PARAMETER_INITIALIZE(weight);

    SYMBOL_TABLE_ENTRY_READ(entry, result, enableFlag, alignment)
    if (result)
    {
        result = weight.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load illuminantWVDataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool illuminantWVDataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enableFlag);
    PARAMETER_INITIALIZE(weight);

    SYMBOL_TABLE_ENTRY_READ(entry, result, enableFlag, alignment)
    if (result)
    {
        result = weight.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load AWBScreeningLevel3Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool AWBScreeningLevel3Type::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(triggerPt);
    PARAMETER_INITIALIZE(triggerData);

    result = triggerPt.Load(entry, alignment);
    if (result)
    {
        result = triggerData.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load AWBScreeningLevel2Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool AWBScreeningLevel2Type::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(triggerPt);
    PARAMETER_INITIALIZE(triggerData);

    result = triggerPt.Load(entry, alignment);

    // Reading Array triggerData from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        triggerDataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, triggerDataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            triggerDataID = pointerEntry->ID;
            DupObjInfo* triggerDataDupInfo = pointerEntry->GetDupObject(triggerDataCount, file, line);
            if (triggerDataDupInfo != nullptr && triggerDataDupInfo->Object != nullptr)
            {
                triggerData = (AWBScreeningLevel3Type*)triggerDataDupInfo->Object;
                if (triggerData == nullptr)
                {
                    if (triggerDataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "triggerData duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            triggerDataDupInfo->File, triggerDataDupInfo->Line, triggerDataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "triggerData duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            triggerDataDupInfo->Line, triggerDataDupInfo->RefCount);
                    }
                }
            }

            if (triggerData == nullptr)
            {
                if (result && triggerDataCount > 0)
                {
                    triggerData = PARAMETER_NEW AWBScreeningLevel3Type[triggerDataCount];
                    (void)pointerEntry->SetDupObject(triggerData, triggerDataCount, file, line);
                }
                if (!result || triggerData == nullptr)
                {
                    if (triggerDataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate triggerData\n");
                    }
                    triggerDataCount = 0;
                }
                for (UINT32 i = 0; result && i < triggerDataCount; i++)
                {
                    result = triggerData[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (triggerData == nullptr)
        {
            triggerDataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load AWBScreeningLevel1Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool AWBScreeningLevel1Type::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(triggerPt);
    PARAMETER_INITIALIZE(triggerData);

    result = triggerPt.Load(entry, alignment);

    // Reading Array triggerData from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        triggerDataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, triggerDataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            triggerDataID = pointerEntry->ID;
            DupObjInfo* triggerDataDupInfo = pointerEntry->GetDupObject(triggerDataCount, file, line);
            if (triggerDataDupInfo != nullptr && triggerDataDupInfo->Object != nullptr)
            {
                triggerData = (AWBScreeningLevel2Type*)triggerDataDupInfo->Object;
                if (triggerData == nullptr)
                {
                    if (triggerDataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "triggerData duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            triggerDataDupInfo->File, triggerDataDupInfo->Line, triggerDataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "triggerData duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            triggerDataDupInfo->Line, triggerDataDupInfo->RefCount);
                    }
                }
            }

            if (triggerData == nullptr)
            {
                if (result && triggerDataCount > 0)
                {
                    triggerData = PARAMETER_NEW AWBScreeningLevel2Type[triggerDataCount];
                    (void)pointerEntry->SetDupObject(triggerData, triggerDataCount, file, line);
                }
                if (!result || triggerData == nullptr)
                {
                    if (triggerDataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate triggerData\n");
                    }
                    triggerDataCount = 0;
                }
                for (UINT32 i = 0; result && i < triggerDataCount; i++)
                {
                    result = triggerData[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (triggerData == nullptr)
        {
            triggerDataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load AWBTriggerScreeningType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool AWBTriggerScreeningType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(triggerPt);
    PARAMETER_INITIALIZE(triggerData);

    result = triggerPt.Load(entry, alignment);

    // Reading Array triggerData from symbol table
    // Do not check result value here because the count value needs to be initialized in this block
    {
        triggerDataCount = 0;
        SYMBOL_TABLE_ENTRY_READ(entry, result, triggerDataCount, alignment)
        constexpr const CHAR* const file {__FILE__};
        constexpr INT32 line {LINE_CONST};
        ParameterFileSymbolTableEntry  pointerEntryCls;
        ParameterFileSymbolTableEntry* const pointerEntry = &pointerEntryCls;
        if (result)
        {
            result = entry->Table->ReadPointerEntry(pointerEntryCls, entry, alignment);
        }

        if (result)
        {
            triggerDataID = pointerEntry->ID;
            DupObjInfo* triggerDataDupInfo = pointerEntry->GetDupObject(triggerDataCount, file, line);
            if (triggerDataDupInfo != nullptr && triggerDataDupInfo->Object != nullptr)
            {
                triggerData = (AWBScreeningLevel1Type*)triggerDataDupInfo->Object;
                if (triggerData == nullptr)
                {
                    if (triggerDataDupInfo->File != nullptr)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "triggerData duplicate found but object is nullptr: %s:%d, RefCount: %d\n",
                            triggerDataDupInfo->File, triggerDataDupInfo->Line, triggerDataDupInfo->RefCount);
                    }
                    else
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "triggerData duplicate found but Object is nullptr: <nullptr file ptr>:%d, RefCount: %d\n",
                            triggerDataDupInfo->Line, triggerDataDupInfo->RefCount);
                    }
                }
            }

            if (triggerData == nullptr)
            {
                if (result && triggerDataCount > 0)
                {
                    triggerData = PARAMETER_NEW AWBScreeningLevel1Type[triggerDataCount];
                    (void)pointerEntry->SetDupObject(triggerData, triggerDataCount, file, line);
                }
                if (!result || triggerData == nullptr)
                {
                    if (triggerDataCount > 0)
                    {
                        PARAMETER_LOG_ERROR(entry->SetManager, "Failed to allocate triggerData\n");
                    }
                    triggerDataCount = 0;
                }
                for (UINT32 i = 0; result && i < triggerDataCount; i++)
                {
                    result = triggerData[i].Load(pointerEntry, alignment);
                }
            }
        }
        if (triggerData == nullptr)
        {
            triggerDataCount = 0;
        }
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load statScreeningDataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool statScreeningDataType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(enableFlag);
    PARAMETER_INITIALIZE(darkThreshold);
    PARAMETER_INITIALIZE(saturationThreshold);

    SYMBOL_TABLE_ENTRY_READ(entry, result, enableFlag, alignment)
    if (result)
    {
        result = darkThreshold.Load(entry, alignment);
    }
    if (result)
    {
        result = saturationThreshold.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load awbStatsProcessorType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool awbStatsProcessorType::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(moduleID);
    PARAMETER_INITIALIZE(module_version);
    PARAMETER_INITIALIZE(statScreeningData);
    PARAMETER_INITIALIZE(illuminantWVData);
    PARAMETER_INITIALIZE(distWVData);
    PARAMETER_INITIALIZE(MLCZ);
    PARAMETER_INITIALIZE(agw);
    PARAMETER_INITIALIZE(SSType);
    PARAMETER_INITIALIZE(refPtData);

    result = moduleID.Load(entry, alignment);
    if (result)
    {
        result = module_version.Load(entry, alignment);
    }
    if (result)
    {
        result = statScreeningData.Load(entry, alignment);
    }
    if (result)
    {
        result = illuminantWVData.Load(entry, alignment);
    }
    if (result)
    {
        result = distWVData.Load(entry, alignment);
    }
    if (result)
    {
        result = MLCZ.Load(entry, alignment);
    }
    if (result)
    {
        result = agw.Load(entry, alignment);
    }
    if (result)
    {
        result = SSType.Load(entry, alignment);
    }
    if (result)
    {
        result = refPtData.Load(entry, alignment);
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module_versionStruct
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool awbStatsProcessorType::module_versionStruct::Load(
    ParameterFileSymbolTableEntry* const entry,
    BYTE const alignment)
{
    bool result = true;

    PARAMETER_INITIALIZE(major_revision);
    PARAMETER_INITIALIZE(minor_revision);
    PARAMETER_INITIALIZE(incr_revision);

    SYMBOL_TABLE_ENTRY_READ(entry, result, major_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, minor_revision, alignment)
    SYMBOL_TABLE_ENTRY_READ(entry, result, incr_revision, alignment)

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload AGWType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void AGWType::Unload(ParameterFileSymbolTable* const __table)
{
    confidence.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload awbMLCZoneConfigType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void awbMLCZoneConfigType::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(Description))
    {
        PARAMETER_DELETE[] Description;
    }
    Description = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload awbMLCZoneDefineType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void awbMLCZoneDefineType::Unload(ParameterFileSymbolTable* const __table)
{
    zoneConfigData.Unload(__table);
    zone.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload MLCZType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void MLCZType::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < detectionZoneCount; i++)
    {
        detectionZone[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(detectionZone))
    {
        PARAMETER_DELETE[] detectionZone;
    }
    detectionZone = nullptr;
    for (UINT32 i = 0; i < MLCZCount; i++)
    {
        MLCZ[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(MLCZ))
    {
        PARAMETER_DELETE[] MLCZ;
    }
    MLCZ = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload distWVDataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void distWVDataType::Unload(ParameterFileSymbolTable* const __table)
{
    weight.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload illuminantWVDataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void illuminantWVDataType::Unload(ParameterFileSymbolTable* const __table)
{
    weight.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload AWBScreeningLevel2Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void AWBScreeningLevel2Type::Unload(ParameterFileSymbolTable* const __table)
{
    if (__table != nullptr && __table->ReleaseDupObject(triggerData))
    {
        PARAMETER_DELETE[] triggerData;
    }
    triggerData = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload AWBScreeningLevel1Type
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void AWBScreeningLevel1Type::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < triggerDataCount; i++)
    {
        triggerData[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(triggerData))
    {
        PARAMETER_DELETE[] triggerData;
    }
    triggerData = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload AWBTriggerScreeningType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void AWBTriggerScreeningType::Unload(ParameterFileSymbolTable* const __table)
{
    for (UINT32 i = 0; i < triggerDataCount; i++)
    {
        triggerData[i].Unload(__table);
    }
    if (__table != nullptr && __table->ReleaseDupObject(triggerData))
    {
        PARAMETER_DELETE[] triggerData;
    }
    triggerData = nullptr;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload statScreeningDataType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void statScreeningDataType::Unload(ParameterFileSymbolTable* const __table)
{
    darkThreshold.Unload(__table);
    saturationThreshold.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload awbStatsProcessorType
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void awbStatsProcessorType::Unload(ParameterFileSymbolTable* const __table)
{
    statScreeningData.Unload(__table);
    illuminantWVData.Unload(__table);
    distWVData.Unload(__table);
    MLCZ.Unload(__table);
    agw.Unload(__table);
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Release the ParameterModule object
/// Requires that this object was created via a ParameterSetManager::GetModule call
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void awbStatsProcessorType::Release()
{
    ((awbStatsProcessorTypeClass*)this)->Release();
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Returns the ParameterModule::Modified value
/// The Modified value is incremented when the module's data or pointer values change
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
UINT32 awbStatsProcessorType::GetModified()
{
    return ((awbStatsProcessorTypeClass*)this)->Modified;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Create module, and return a new object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
ParameterModule* awbStatsProcessorTypeClass::Create(
    ModuleData*    moduleData,
    DefaultModule* const defModule) const
{
    awbStatsProcessorTypeClass* cls = nullptr;

    if (PARAMETER_STRCMP(Type, moduleData->Type) == 0 && Version.Value == moduleData->Version.Value)
    {
        const UINT32 id = moduleData->DuplicateID > 0 ? moduleData->DuplicateID : moduleData->ID;

        ParameterModule* const module = defModule->Find(id);
        if (module != nullptr)
        {
            cls = (awbStatsProcessorTypeClass*)module;
        }
        else
        {
            cls = PARAMETER_NEW awbStatsProcessorTypeClass(GetName(moduleData->Type), moduleData);
            cls->SymbolTableID = id;
            defModule->AddModule((ParameterModule*)cls);
        }
    }
    else if (Version.Value != moduleData->Version.Value)
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create awbStatsProcessorTypeClass, binary version (%lld) does not match source version (%lld)\n",
            moduleData->Version.Value, Version.Value);
    }
    else
    {
        PARAMETER_LOG_ERROR(moduleData->SetManager, "Unable to create awbStatsProcessorTypeClass, binary name (%s) does not match source name (%s)\n",
            moduleData->Type, Type);
    }

    return (ParameterModule*)cls;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Load module data, return true is successful
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
bool awbStatsProcessorTypeClass::LoadModule(
    ParameterFileSymbolTable* const table)
{
    bool result = true;

    if (!Loaded)
    {
        BYTE const alignment = table->Alignment;
        awbStatsProcessorTypeClass* const cls = this;

        ParameterFileSymbolTableEntry  entryObj;
        ParameterFileSymbolTableEntry* const entry = &entryObj;
        // With EzTune enabled, the unused upper byte of SymbolTableID value can change, so clear it
        result = table->Find(entryObj, SymbolTableID & 0x00ffffff);

        if (!result)
        {
            PARAMETER_LOG_ERROR(entry->SetManager, "awbStatsProcessorTypeClass::LoadModule Failed to find module ID (%d) in Symbol Table\n", SymbolTableID);
        }

        if (result)
        {
            result = cls->Load(entry, alignment);
        }
        Modified++;
        Loaded = true;
    }

    if (!result)
    {
        /// Module failed to fully load, unload it
        UnloadModule();
    }

    return result;
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// Unload module data
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void awbStatsProcessorTypeClass::UnloadModule()
{
    if (Loaded)
    {
        if (Data != nullptr && Data->SymbolTable != nullptr)
        {
            Unload(Data->SymbolTable);
        }
        else
        {
            PARAMETER_LOG_ERROR(Data != nullptr ? Data->SetManager : nullptr, "UnloadModule %s called with nullptr "
                "Data->SymbolTable object\n", Name);
            Unload(nullptr);
        }
        Loaded = false;
    }
}

////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
/// /// Release the ParameterModule object
////////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
void awbStatsProcessorTypeClass::Release()
{
    ParameterModule::Release();
}

AWBRSTATSPROCESSOR_NAMESPACE_END
